# Ansible Rollout Playbooks

This repository contains a collection of Ansible playbooks and roles for setting up
my base Debian systems.

## Roles
- **base_setup** - Role to set up a base system
  - Installs basic packages
  - Sets time zone
  - Sets up authorized key for user
  - Creates user with or without password
- **system_update** - Role to update the system
- **tor** - Role to install Tor

## Playbooks
- **playbooks/setup_base_system.yml** - Sets up the base system
  - Can generate passwords with the `generate_user_password` variable
  - Passwords will be placed in a file called `generated_passwords.txt`
- **playbooks/update_systems.yml** - Updates the systems
- **playbooks/install_tor.yml** - Installs Tor for all hosts in the `tor_systems` group

## Testing
If you would like to test out the plays before using them on your live systems, this
repository includes a Vagrantfile, Ansible test configuration, and a test inventory.

To test the plays, run the following commands:
```bash
vagrant up
ANSIBLE_CONFIG=test_ansible.cfg ansible-playbook playbooks/setup_base_system.yml -e "generate_user_password=yes"
ANSIBLE_CONFIG=test_ansible.cfg ansible-playbook playbooks/update_systems.yml
ANSIBLE_CONFIG=test_ansible.cfg ansible-playbook playbooks/install_tor.yml
```

This will set up the base system with passwords generated for the user, update the systems,
and install Tor on the `tor_systems` group.

## Contributors
- [agatha](https://git.juggalol.com/agatha)
